@@ -2,6 +2,7 @@
 @author:XuMing(xuming624@qq.com)
 @description: Server
 """
+import argparse
 import uvicorn
 import sys
 import os
@@ -11,13 +12,16 @@ import torch
 from loguru import logger
 
 sys.path.append('..')
-from autocomplete.gpt2 import Infer
+from autocomplete.gpt2_coder import GPT2Coder
 
 pwd_path = os.path.abspath(os.path.dirname(__file__))
 use_cuda = torch.cuda.is_available()
 # Use finetuned GPT2 model
-model_dir = os.path.join(pwd_path, "outputs/fine-tuned/")
-gpt2_infer = Infer(model_name="gpt2", model_dir=model_dir, use_cuda=use_cuda)
+parser = argparse.ArgumentParser()
+parser.add_argument("--model_name_or_path", type=str, default="shibing624/code-autocomplete-gpt2-base",
+                    help="Model save dir or model name")
+args = parser.parse_args()
+model = GPT2Coder(args.model_name_or_path)
 
 # define the app
 app = FastAPI()
@@ -38,8 +42,8 @@ async def index():
 async def autocomplete(q: str = Query(..., min_length=1, max_length=512, title='query')):
     try:
         # Generate text using the model. Verbose set to False to prevent logging generated sequences.
-        generated = gpt2_infer.predict(q)
-        result_dict = generated
+        generated = model.generate(q)
+        result_dict = generated[0]
         logger.debug(f"Successfully autocomplete, q:{q}, res:{result_dict}")
         return result_dict
     except Exception as e:
